gotextsanitizer

package module
v0.0.0-...-7adfa39 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 9, 2024 License: GPL-2.0 Imports: 1 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Unidecode

func Unidecode(input string) (string, error)

Convert UTF-8 string into an ASCII representation of it.

Please note that perfect transliteration is not guaranteed. It is not intended to be used for primary display purposes, but rather for secondary purposes. such as urls, tags, etc.

If you have any corrections/comments to make about the transliteration, please report it at https://github.com/avian2/unidecode. This function is only a port of this library and the mapping is generated directly from it. if it's not about transliteration (error, crash, ...) you should report it to me.

Types

This section is empty.

Jump to